@@ -35,7 +35,6 @@ protected:
   void keyPressEvent( QKeyEvent *e ) override;
   void leaveEvent( QEvent *e ) override;
   void mousePressEvent( QMouseEvent *e ) override;
-  void mouseReleaseEvent( QMouseEvent *e ) override;
   void mouseMoveEvent( QMouseEvent *e ) override;
   void wheelEvent( QWheelEvent *e ) override;
   void paintEvent( QPaintEvent *e ) override;
@@ -64,14 +63,7 @@ private:
   void stopNativeMove( QMouseEvent *e );
   QString indicatorText() const;
 
-  enum RulerState {
-    StateNone,
-    StateMove,
-    StateBegin,
-    StateEnd
-  };
   QCursor mCrossCursor;
-  RulerState mRulerState = StateNone;
   QPoint mLastClickPos;
   QPoint mDragOffset;
   bool mHorizontal = false;
@@ -94,7 +86,6 @@ private:
 
   void setHorizontal( bool horizontal );
 
-  bool isResizing() const;
   int length() const;
   QPoint localCursorPos() const;
   qreal pixelRatio() const;
